<?php

namespace Form\FullForm;

/**
 * A FormInterface represents a form and can be used in templates to render forms
 */
interface FormInterface
{
    /**
     * returns a value that can be used as the name attribute of a html form
     *
     * @return string
     */
    public function getName();

    /**
     * @return FieldInterface[]
     */
    public function getFields();

    /**
     * @param string $name
     * @return FieldInterface|null
     */
    public function getField($name);

    /**
     * @param string $tag
     * @return FieldInterface[]
     */
    public function getFieldsByTag($tag);

    /**
     * @return string
     */
    public function getSubmitButtonText();

    /**
     * @return bool
     */
    public function isValid();

    /**
     * @return string
     */
    public function getSuccessText();

    /**
     * @return bool
     */
    public function hasError();

    /**
     * @return string|null
     */
    public function getErrorText();

    /**
     * Returns an instance of FormInterface for which hasError() MUST return true
     * Returned instance getErrorText CAN return $text if provided
     *
     * @param string $text
     * @return static
     */
    public function withError($text = null);

    /**
     * Returns an instance of FormInterface for which hasError() MUST return false
     * Returned instance getErrorText MUST return null
     *
     * @return static
     */
    public function withoutError();
}
