Form Component
=================

![build status](http://phpci.bydedi.com/build-status/image/5)

Composant pour gérer la validation des formulaires

Créer un formulaire
-------------------

Exemple de création de formulaire :

```php
<?php

// Chaque formulaire doit herité de la classe Form
class LoginForm extends \Form\Form
{
    // on définit dans le constructeur la liste des champs du formulaire et leur regles de validation
    // on utilise l'objet \Form\Field pour créer un champ
    public function __construct()
    {
        parent::__construct();

        $this
            ->add(
                new \Form\Field(
                    "client_email",
                    array(
                        "not_empty" => new \Form\Constraint\NotBlank(),
                        "is_mail" => new \Form\Constraint\Mail(),
                    ),
                    array(
                        "not_empty" => "Vous devez remplir votre email.",
                        "is_mail" => "Vous devez utiliser un email correct.",
                    )
                )
            )
            ->add(
                new \Form\Field(
                    "client_password",
                    array(
                        "not_empty" => new \Form\Constraint\NotBlank(),
                    ),
                    array(
                        "not_empty" => "Vous devez remplir un mot de passe."
                    )
                )
            )
        ;
    }
}
```
    
L'objet `\Form\Field` prend 3 paramètres :

* le nom du champ du formulaire
* un tableau d'objet Constraint avec les regles de validation
* un tableau avec les messages d'erreur pour chaque regles de validation


Les contraintes
---------------

Chaque contraintes (regles de validation) est représenté par un objet

Pour créer une nouvelle contrainte, il faut créer une classe qui herite de `Constraint`

```php
<?php

namespace Form\Constraint;

class MyConstraint extends Constraint
{
    public function isValid($value)
    {
     // TODO: Implement isValid() method.
    }
}
```

FullForm
--------

Des interfaces FullForm ont été définies, décrivant en détail les caractéristiques d'un formulaire.

Ces interfaces ont pour but de permettre au Front End de développer des templates pour afficher n'importe quel implémentation de FullForm.

Un exemple d'implémentation peut être trouvé dans le package bydedi\module-custom-form